# pygp_particle_filter

This is a particle-path SLAM implementation that uses Gaussian Process Regression to determine particle weights based on the consistency between current and past scans of a particle. You can install it from:

>pip install pygp-particle-filter

or alternatively clone the git repository at `https://github.com/miquelmassot/pygp_particle_filter`, and install the packages with the following command from its root directory. 

>pip install -e .

The example jupyter notebook illustrates basic usage. 

A more full explanation of the theory and functions are coverend in University of Southampton `FEEG6043: Intelligent Mobile Robotics` moduel notes and the associated tutorial.